<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Использование</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Dock Preview</source>
        <translation>Предпросмотр дока</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Add New Application</source>
        <translation>Добавить новое приложение</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Add application</source>
        <translation>Добавить приложение</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Delete this application</source>
        <translation>Удалить это приложение</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Border</source>
        <translation>Граница</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <source>Background</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <location filename="../mainwindow.cpp" line="861"/>
        <location filename="../mainwindow.cpp" line="979"/>
        <location filename="../mainwindow.cpp" line="1017"/>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>Select icon...</source>
        <translation>Выберите значок...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <location filename="../mainwindow.cpp" line="102"/>
        <location filename="../mainwindow.cpp" line="800"/>
        <location filename="../mainwindow.cpp" line="865"/>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Select...</source>
        <translation>Выбор...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Move right</source>
        <translation>Сдвинуть вправо</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="146"/>
        <source>Move left</source>
        <translation>Сдвинуть влево</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <location filename="../mainwindow.ui" line="338"/>
        <location filename="../mainwindow.ui" line="514"/>
        <location filename="../mainwindow.ui" line="579"/>
        <source>Click to select different color...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Apply style to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Hover Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>36x36</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>40x40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Hover Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <source>Display help </source>
        <translation>Показать справку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="726"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="755"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="758"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="797"/>
        <source>Quit application</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="800"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="848"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <source>Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Добавляйте в док приложения по одному
2. Выберите файл .desktop или введите команду для нужного вам приложения
3. Выберите для значка атрибуты размера, фона (стандартно - чёрный)  и границы
4. Нажмите &quot;Добавить приложение&quot;, чтобы продолжить или &quot;Сохранить&quot; для завершения</translation>
    </message>
    <message>
        <source>black</source>
        <translation type="vanished">черный</translation>
    </message>
    <message>
        <source>white</source>
        <translation type="vanished">белый</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Эта средство позволяет создать новую док-панель с несколькими приложениями. Также вы можете изменить или удалить ранее созданную док-панель.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>Operation mode</source>
        <translation>Режим работы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>&amp;Move</source>
        <translation>&amp;Переместить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="173"/>
        <source>&amp;Edit</source>
        <translation>&amp;Изменить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <source>C&amp;reate</source>
        <translation>С&amp;оздать</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Dock name</source>
        <translation>Название дока</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Введите имя для показа в Меню:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Select dock to delete</source>
        <translation>Выберите, какой док удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Confirmation</source>
        <translation>Подтверждение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Вы уверены, что хотите удалить %1?</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="vanished">&amp;Отмена</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Дальше</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Select dock to move</source>
        <translation>Выберите док для перемещения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <location filename="../mainwindow.cpp" line="426"/>
        <location filename="../mainwindow.cpp" line="641"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation>Файлы доков (*.mxdk);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Error</source>
        <translation type="unfinished">Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Failed to delete the selected dock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Could not open file</source>
        <translation>Не удалось открыть файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Overwrite?</source>
        <translation>Перезаписать?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>Вы хотите перезаписать файл дока?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Dock saved</source>
        <translation>Док сохранён</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>Док был сохранён.

Для изменения вновь созданного дока, выберите &apos;Изменить существующий док&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>MX Dockmaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="734"/>
        <source>Description goes here</source>
        <translation>Здесь идёт описание</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="737"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>Select .desktop file</source>
        <translation>Выберите файл .desktop.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Файлы desktop (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="925"/>
        <source>Select a dock file</source>
        <translation>Выберите файл дока.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="930"/>
        <source>No file selected</source>
        <translation>Файл не выбран</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="931"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>Вы не выбрали файл дока, подлежащий изменению.
Создаётся новый док.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="938"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Не удалось открыть выбранный файл.
Создаётся новый док.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="946"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Изменяйте приложения по одному используя кнопки Назад и Вперёд
2. Добавляйте или удаляйте приложения как вам нравится
3. По окончанию нажмите Сохранить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1023"/>
        <source>Select icon</source>
        <translation>Выберите значок</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1024"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Значки (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Расположение дока</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>Вверху по центру</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>Внизу слева</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>Внизу по центру</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>Вверху слева</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>Вверху справа</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>Слева по центру</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>Справа по центру</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>Внизу справа</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>Справа вверху</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>Слева вверху</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>Слева внизу</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>Справа внизу</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Выберите расположение дока</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>License</source>
        <translation type="vanished">Лицензия</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Список изменений</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Отмена</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Закрыть</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Ошибка</translation>
    </message>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Вы должны запустить эту программу как обычный пользователь.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation type="unfinished">Лицензия</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Список изменений</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмена</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <location filename="../main.cpp" line="75"/>
        <source>Error</source>
        <translation type="unfinished">Ошибка</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">Вы должны запустить эту программу как обычный пользователь.</translation>
    </message>
</context>
</TS>
